@@ -9,14 +9,14 @@
 // You should have received a copy of the MIT License along with this software.
 // If not, see <https://opensource.org/licenses/MIT>.
 
-mod arithm;
-mod bitwise;
-pub mod number;
-#[allow(clippy::module_inception)]
-mod reg;
+//! AluVM registers system
 
-pub use number::{MaybeNumber, Number, Step};
-pub use reg::{
-    Reg16, Reg32, Reg8, RegA, RegA2, RegAF, RegAR, RegBlockAFR, RegBlockAR, RegF, RegR,
-    RegisterSet, Registers,
+mod core_regs;
+mod families;
+mod indexes;
+
+pub use core_regs::{CoreRegs, CALL_STACK_SIZE};
+pub use families::{
+    RegA, RegA2, RegAF, RegAFR, RegAR, RegBlockAFR, RegBlockAR, RegF, RegR, RegisterFamily,
 };
+pub use indexes::{Reg16, Reg32, Reg8};
